@@ -19,15 +19,16 @@
 
 import logging
 
-import gtk
-import pango
+from gi.repository import Gdk
+from gi.repository import Gtk
+from gi.repository import Pango
 
 from rednotebook.util import markup
 from rednotebook.util import utils
 from rednotebook import undo
 
 
-class CategoriesTreeView(object):
+class CategoriesTreeView:
     def __init__(self, tree_view, main_window):
         self.tree_view = tree_view
 
@@ -41,14 +42,14 @@ class CategoriesTreeView(object):
         self.statusbar = self.main_window.statusbar
 
         # create a TreeStore with one string column to use as the model
-        self.tree_store = gtk.TreeStore(str)
+        self.tree_store = Gtk.TreeStore(str)
 
         # create the TreeView using tree_store
         self.tree_view.set_model(self.tree_store)
 
         # create the TreeViewColumn to display the data
-        self.tvcolumn = gtk.TreeViewColumn()
-        label = gtk.Label()
+        self.tvcolumn = Gtk.TreeViewColumn()
+        label = Gtk.Label()
         label.set_markup('<b>' + _('Tags') + '</b>')
         label.show()
         self.tvcolumn.set_widget(label)
@@ -57,7 +58,7 @@ class CategoriesTreeView(object):
         self.tree_view.append_column(self.tvcolumn)
 
         # create a CellRendererText to render the data
-        self.cell = gtk.CellRendererText()
+        self.cell = Gtk.CellRendererText()
 
         self.cell.set_property('editable', True)
         self.cell.connect('edited', self.edited_cb, self.tree_store)
@@ -68,7 +69,6 @@ class CategoriesTreeView(object):
 
         """ set the cell "text" attribute to column 0 - retrieve text
             from that column in tree_store"""
-        #self.tvcolumn.add_attribute(self.cell, 'text', 0)
         self.tvcolumn.add_attribute(self.cell, 'markup', 0)
 
         # make it searchable
@@ -85,7 +85,7 @@ class CategoriesTreeView(object):
         self.tree_view.connect('key-press-event', self.on_key_press_event)
 
         # Wrap lines
-        self.cell.props.wrap_mode = pango.WRAP_WORD
+        self.cell.props.wrap_mode = Pango.WrapMode.WORD
         self.cell.props.wrap_width = 200
         self.tree_view.connect_after("size-allocate", self.on_size_allocate, self.tvcolumn, self.cell)
 
@@ -102,7 +102,7 @@ class CategoriesTreeView(object):
         self.categories.sort(key=utils.sort_asc)
 
     def node_on_top_level(self, iter):
-        if not type(iter) == gtk.TreeIter:
+        if not type(iter) == Gtk.TreeIter:
             # iter is a path -> convert to iter
             iter = self.tree_store.get_iter(iter)
         assert self.tree_store.iter_is_valid(iter)
@@ -156,14 +156,13 @@ class CategoriesTreeView(object):
         """
         Recursive Method for adding the content
         """
-        # We want to order the entries ascendingly
-        ascending = lambda (key, value): key.lower()
-
-        for key, value in sorted(element_content.iteritems(), key=ascending):
+        for key, value in sorted(
+                iter(element_content.items()),
+                key=lambda key_value: key_value[0].lower()):
             if key is not None:
                 key_pango = markup.convert_to_pango(key)
             new_child = self.tree_store.append(parent, [key_pango])
-            if not value is None:
+            if value is not None:
                 self.add_element(new_child, value)
 
     def set_day_content(self, day):
@@ -215,7 +214,7 @@ class CategoriesTreeView(object):
         self.tvcolumn.clear_attributes(self.cell)
         self.tvcolumn.add_attribute(self.cell, 'text', 0)
 
-        pango_markup = self.tree_store.get_value(iter, 0).decode('utf-8')
+        pango_markup = self.tree_store.get_value(iter, 0)
 
         # Reset the renderer to use markup
         self.tvcolumn.clear_attributes(self.cell)
@@ -279,9 +278,13 @@ class CategoriesTreeView(object):
             self.tree_store.append(category_iter, [entry_pango])
 
         if not undoing:
-            undo_func = lambda: self.delete_node(self.find_iter(category, entry), undoing=True)
-            redo_func = lambda: self.add_entry(category, entry, undoing=True)
-            action = undo.Action(undo_func, redo_func, 'categories_tree_view')
+            def undo_func():
+                self.delete_node(self.find_iter(category, entry), undoing=True)
+
+            def redo_func():
+                self.add_entry(category, entry, undoing=True)
+
+            action = undo.Action(undo_func, redo_func)
             self.undo_redo_manager.add_action(action)
 
         self.tree_view.expand_all()
@@ -313,7 +316,7 @@ class CategoriesTreeView(object):
             category = self.get_iter_value(category_iter)
             content = self._get_element_content(category_iter)
             if content:
-                entries = content.keys()
+                entries = list(content.keys())
             else:
                 entries = []
 
@@ -334,7 +337,7 @@ class CategoriesTreeView(object):
                     delete_iter = self.find_iter(category, entry)
                     self.delete_node(delete_iter, undoing=True)
 
-            action = undo.Action(undo_func, redo_func, 'categories_tree_view')
+            action = undo.Action(undo_func, redo_func)
             self.undo_redo_manager.add_action(action)
 
         # Update cloud
@@ -346,29 +349,15 @@ class CategoriesTreeView(object):
             self.delete_node(selected_iter)
             return
 
-    def on_key_press_event(self, widget, event):
-        """
-        @param widget - gtk.TreeView - The Tree View
-        @param event - gtk.gdk.event - Event information
-
-        Delete an annotation node when user hits "Delete"
-        """
-        keyname = gtk.gdk.keyval_name(event.keyval)
-        logging.info('Pressed key: %s' % keyname)
-
+    def on_key_press_event(self, _view, event):
+        keyname = Gdk.keyval_name(event.keyval)
         if keyname == 'Delete':
             self._on_delete_entry_clicked(None)
-        elif keyname == 'Menu':
-            # Does not work
-            logging.info('Context Menu does not work')
-            self.context_menu.popup(None, None, None, 0, event.time)
+        elif keyname == 'F2':
+            self._on_change_entry_clicked(None)
 
     def on_button_press_event(self, widget, event):
-        """
-        @param widget - gtk.TreeView - The Tree View
-        @param event - gtk.gdk.event - Event information
-        """
-        #Get the path at the specific mouse position
+        # Get the path at the specific mouse position.
         path = widget.get_path_at_pos(int(event.x), int(event.y))
         if (path is None):
             """If we didn't get a path then we don't want anything
@@ -385,8 +374,8 @@ class CategoriesTreeView(object):
         delete_entry_item.set_sensitive(something_selected)
 
         if (event.button == 3):
-            #This is a right-click
-            self.context_menu.popup(None, None, None, event.button, event.time)
+            # This is a right-click.
+            self.context_menu.popup(None, None, None, None, event.button, event.time)
 
     def _get_context_menu(self):
         context_menu_xml = """
@@ -401,15 +390,15 @@ class CategoriesTreeView(object):
         uimanager = self.main_window.uimanager
 
         # Create an ActionGroup
-        actiongroup = gtk.ActionGroup('ContextMenuActionGroup')
+        actiongroup = Gtk.ActionGroup('ContextMenuActionGroup')
 
         # Create actions
         actiongroup.add_actions([
-            ('ChangeEntry', gtk.STOCK_EDIT, _('Change this text'),
+            ('ChangeEntry', Gtk.STOCK_EDIT, _('Change this text'),
              None, None, self._on_change_entry_clicked),
-            ('AddEntry', gtk.STOCK_NEW, _('Add a new entry'),
+            ('AddEntry', Gtk.STOCK_NEW, _('Add a new entry'),
              None, None, self._on_add_entry_clicked),
-            ('Delete', gtk.STOCK_DELETE, _('Delete this entry'),
+            ('Delete', Gtk.STOCK_DELETE, _('Delete this entry'),
              None, None, self._on_delete_entry_clicked),
         ])
 
@@ -425,8 +414,10 @@ class CategoriesTreeView(object):
 
     def _on_change_entry_clicked(self, action):
         iter = self.get_selected_node()
-        self.tree_view.set_cursor(self.tree_store.get_path(iter),
-                                focus_column=self.tvcolumn, start_editing=True)
+        self.tree_view.set_cursor(
+            self.tree_store.get_path(iter),
+            self.tvcolumn,
+            True)
 
     def _on_add_entry_clicked(self, action):
         iter = self.get_selected_node()
@@ -461,8 +452,8 @@ class CategoriesTreeView(object):
         new_width = allocation.width - sum(c.get_width() for c in other_columns)
         new_width -= treeview.style_get_property("horizontal-separator") * 2
 
-        ## Customize for treeview with expanders
-        ## The behaviour can only be fitted to one depth -> take the second one
+        # Customize for treeview with expanders.
+        # The behaviour can only be fitted to one depth -> take the second one.
         new_width -= treeview.style_get_property('expander-size') * 3
 
         if cell.props.wrap_width == new_width or new_width <= 0:
@@ -475,5 +466,5 @@ class CategoriesTreeView(object):
             iter = store.iter_next(iter)
         treeview.set_size_request(0, -1)
 
-        ## The heights may have changed
+        # The heights may have changed.
         column.queue_resize()
