@@ -394,10 +394,11 @@ class Journal:
     def save_old_day(self):
         '''Order is important'''
         old_content = self.day.content
-        self.day.content = self.frame.categories_tree_view.get_day_content()
-        self.day.text = self.frame.get_day_text()
+        new_content = self.frame.categories_tree_view.get_day_content()
+        new_content['text'] = self.frame.get_day_text()
+        self.day.content = new_content
 
-        content_changed = (old_content != self.day.content)
+        content_changed = (old_content != new_content)
         if content_changed:
             self.month.edited = True
 
@@ -575,7 +576,12 @@ def main():
         logging.debug('Trying to enter the gtk main loop')
         Gtk.main()
     except KeyboardInterrupt:
-        sys.exit()
+        pass
+
+    try:
+        logging.info("Peak memory: {} KiB".format(filesystem.get_peak_memory_in_kb()))
+    except Warning:
+        pass
 
 
 if __name__ == '__main__':
