@@ -18,25 +18,23 @@
 # -----------------------------------------------------------------------
 
 from collections import defaultdict
-import logging
 
 
-class Action(object):
-    def __init__(self, undo_function, redo_function, tags):
+class Action:
+    def __init__(self, undo_function, redo_function):
         self.undo_function = undo_function
         self.redo_function = redo_function
-        self.tags = tags
 
 
-class UndoRedoManager(object):
-    size = 100
-    buffer = 20
+class UndoRedoManager:
+    SIZE = 100
+    BUFFER = 20
 
     def __init__(self, main_window):
         self.main_window = main_window
 
-        self.undo_action = self.main_window.uimanager.get_widget('/MainMenuBar/Edit/Undo').get_action()
-        self.redo_action = self.main_window.uimanager.get_widget('/MainMenuBar/Edit/Redo').get_action()
+        self.undo_action = self.main_window.uimanager.get_action('/MainMenuBar/Edit/Undo')
+        self.redo_action = self.main_window.uimanager.get_action('/MainMenuBar/Edit/Redo')
 
         self.undo_stacks = defaultdict(list)
         self.redo_stacks = defaultdict(list)
@@ -46,10 +44,12 @@ class UndoRedoManager(object):
 
     @property
     def undo_stack(self):
+        assert self.current_stack is not None
         return self.undo_stacks[self.current_stack]
 
     @property
     def redo_stack(self):
+        assert self.current_stack is not None
         return self.redo_stacks[self.current_stack]
 
     def set_stack(self, stack):
@@ -57,24 +57,19 @@ class UndoRedoManager(object):
         self.update_buttons()
 
     def add_action(self, action):
-        '''
-        Arguments are functions that encode what there is to to to redo and undo
-        the action
-        '''
         self.undo_stack.append(action)
 
-        # Delete some items, if the undo stack grows too big
-        if len(self.undo_stack) > self.size + self.buffer:
-            del self.undo_stack[:self.buffer]
+        # Delete some items, if the undo stack grows too big.
+        if len(self.undo_stack) > self.SIZE + self.BUFFER:
+            del self.undo_stack[:self.BUFFER]
 
-        # When a new action has been made, forget all redos
+        # When a new action has been made, forget all redos.
         del self.redo_stack[:]
 
         self.update_buttons()
 
     def undo(self, *args):
         assert self.can_undo()
-        logging.debug('Undo')
 
         action = self.undo_stack.pop()
         action.undo_function()
@@ -84,7 +79,6 @@ class UndoRedoManager(object):
 
     def redo(self, *args):
         assert self.can_redo()
-        logging.debug('Redo')
 
         action = self.redo_stack.pop()
         action.redo_function()
@@ -93,10 +87,10 @@ class UndoRedoManager(object):
         self.update_buttons()
 
     def can_undo(self):
-        return len(self.undo_stack) > 0
+        return bool(self.undo_stack)
 
     def can_redo(self):
-        return len(self.redo_stack) > 0
+        return bool(self.redo_stack)
 
     def update_buttons(self):
         self.undo_action.set_sensitive(self.can_undo())
