@@ -17,17 +17,18 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-import locale
 import datetime
 
 
 one_day = datetime.timedelta(days=1)
 
+
 def get_year_and_month_from_date(date):
     year_and_month = date.strftime('%Y-%m')
     assert len(year_and_month) == 7
     return year_and_month
 
+
 def get_date_from_date_string(date_string):
     date = datetime.datetime.strptime(date_string, '%Y-%m-%d')
     return datetime.date(date.year, date.month, date.day)
@@ -35,10 +36,12 @@ def get_date_from_date_string(date_string):
 # Number of days per month (except for February in leap years)
 month_days = [0, 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
 
+
 def isleap(year):
     """Return True for leap years, False for non-leap years."""
     return year % 4 == 0 and (year % 100 != 0 or year % 400 == 0)
 
+
 def get_number_of_days(year, month):
     '''
     Return the number of days in a given month of a given year
@@ -46,6 +49,7 @@ def get_number_of_days(year, month):
     days = month_days[month] + (month == 2 and isleap(year))
     return days
 
+
 def format_date(format_string, date=None):
     if date is None:
         date = datetime.datetime.now()
@@ -54,13 +58,10 @@ def format_date(format_string, date=None):
     except ValueError:
         # This happens if the format string ends with "%"
         date_string = _('Incorrect date format')
-    # Turn date into unicode string
-    locale_name, locale_encoding = locale.getlocale()
-    # locale_encoding is None if the value cannot be determined
-    locale_encoding = locale_encoding or 'UTF-8'
-    try:
-        date_string = date_string.decode(locale_encoding, 'replace')
-    except LookupError:
-        # Encoding was not found.
-        date_string = date_string.decode('UTF-8', 'replace')
     return date_string
+
+
+def same_month(date1, date2):
+    return (
+        date1 is not None and date2 is not None and
+        date1.month == date2.month and date1.year == date2.year)
