@@ -22,14 +22,8 @@ import os
 import re
 import sys
 
-import gobject
-import pango
-
-# Testing
-if __name__ == '__main__':
-    sys.path.insert(0, '../../')
-    logging.basicConfig(level=logging.DEBUG,
-                    format='%(levelname)-8s %(message)s',)
+from gi.repository import GObject
+from gi.repository import Pango
 
 from rednotebook.external import txt2tags
 from rednotebook.data import HASHTAG
@@ -42,21 +36,25 @@ REGEX_HTML_LINK = r'<a.*?>(.*?)</a>'
 
 # pic [""/home/user/Desktop/RedNotebook pic"".png]
 PIC_NAME = r'\S.*?\S|\S'
-PIC_EXT = r'(?:png|jpe?g|gif|eps|bmp)'
+PIC_EXT = r'(?:png|jpe?g|gif|eps|bmp|svg)'
 REGEX_PIC = re.compile(r'(\["")(%s)("")(\.%s)(\?\d+)?(\])' % (PIC_NAME, PIC_EXT), flags=re.I)
 
 # named local link [my file.txt ""file:///home/user/my file.txt""]
 # named link in web [heise ""http://heise.de""]
-REGEX_NAMED_LINK = re.compile(r'(\[)(.*?)(\s"")(\S.*?\S)(""\])', flags=re.I | re.L)
+REGEX_NAMED_LINK = re.compile(r'(\[)(.*?)(\s"")(\S.*?\S)(""\])', flags=re.I)
+
+ESCAPE_COLOR = r'XBEGINCOLORX\1XSEPARATORX\2XENDCOLORX'
+COLOR_ESCAPED = r'XBEGINCOLORX(.*?)XSEPARATORX(.*?)XENDCOLORX'
 
 TABLE_HEAD_BG = '#aaa'
 
 CHARSET_UTF8 = '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />'
+PRINT_FUNCTION = '<script></script>'
 
 CSS = """\
 <style type="text/css">
     body {
-        font-family: Ubuntu, Helvetica, Arial, sans-serif;
+        font-family: %(font)s;
     }
     <!-- Don't split last line between pages.
          This fix is only supported by Opera -->
@@ -88,7 +86,7 @@ CSS = """\
         text-align: left;
         padding-top: 5px;
         padding-bottom: 4px;
-        background-color: %(TABLE_HEAD_BG)s;
+        background-color: %(table_head_bg)s;
         color: #ffffff;
     }
     hr.heavy {
@@ -96,13 +94,11 @@ CSS = """\
         background-color: black;
     }
 </style>
-""" % globals()
+"""
 
 # MathJax
 FORMULAS_SUPPORTED = True
-MATHJAX_FILE = 'http://cdn.mathjax.org/mathjax/latest/MathJax.js'
-logging.info('MathJax location: %s' % MATHJAX_FILE)
-MATHJAX_FINISHED = 'MathJax finished'
+MATHJAX_FILE = 'https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.1/MathJax.js'
 
 # Explicitly setting inlineMath: [ ['\\(','\\)'] ] doesn't work.
 # Using defaults:
@@ -111,27 +107,19 @@ MATHJAX_FINISHED = 'MathJax finished'
 MATHJAX_DELIMITERS = ['$$', '\\(', '\\)', r'\\[', '\\]']
 MATHJAX = """\
 <script type="text/x-mathjax-config">
-  MathJax.Hub.Config({
-  messageStyle: "none",
-  config: ["MMLorHTML.js"],
-  jax: ["input/TeX","input/MathML","output/HTML-CSS","output/NativeMML"],
-  tex2jax: {},
-  extensions: ["tex2jax.js","mml2jax.js","MathMenu.js","MathZoom.js"],
-  TeX: {
-    extensions: ["AMSmath.js","AMSsymbols.js","noErrors.js","noUndefined.js"]
-  }
-  });
+  MathJax.Hub.Config({{
+    messageStyle: "none",
+    config: ["MMLorHTML.js"],
+    jax: ["input/TeX","input/MathML","output/HTML-CSS","output/NativeMML"],
+    tex2jax: {{}},
+    extensions: ["tex2jax.js","mml2jax.js","MathMenu.js","MathZoom.js"],
+    TeX: {{
+      extensions: ["AMSmath.js","AMSsymbols.js","noErrors.js","noUndefined.js"]
+    }}
+  }});
 </script>
-<script type="text/javascript"
-  src="%s">
-</script>
-<script>
-  MathJax.Hub.Queue(function () {
-    document.title = "%s";
-    document.title = "RedNotebook";
-  });
-</script>
-""" % (MATHJAX_FILE, MATHJAX_FINISHED)
+<script type="text/javascript" src="{MATHJAX_FILE}"></script>
+""".format(**locals())
 
 
 def convert_categories_to_markup(categories, with_category_title=True):
@@ -141,7 +129,7 @@ def convert_categories_to_markup(categories, with_category_title=True):
     else:
         markup = ''
 
-    for category, entry_list in categories.iteritems():
+    for category, entry_list in categories.items():
         markup += '- ' + category + '\n'
         for entry in entry_list:
             markup += '  - ' + entry + '\n'
@@ -177,10 +165,9 @@ def get_markup_for_day(day, with_text=True, with_tags=True, categories=None, dat
         # "Export no categories" selected
         export_categories = []
 
-
     if export_categories:
-        export_string += '\n\n\n' + convert_categories_to_markup(export_categories,
-                                                            with_category_title=with_text)
+        export_string += '\n\n\n' + convert_categories_to_markup(
+            export_categories, with_category_title=with_text)
     elif with_text:
         export_string += '\n\n'
 
@@ -193,29 +180,35 @@ def get_markup_for_day(day, with_text=True, with_tags=True, categories=None, dat
     return ''
 
 
-def _get_config(type):
+def _get_config(target, options):
 
     config = {}
 
     # Set the configuration on the 'config' dict.
     config = txt2tags.ConfigMaster()._get_defaults()
 
+    config['outfile'] = txt2tags.MODULEOUT  # results as list
+    config['target'] = target
+
     # The Pre (and Post) processing config is a list of lists:
     # [ [this, that], [foo, bar], [patt, replace] ]
     config['postproc'] = []
     config['preproc'] = []
+    config['style'] = []
 
     # Allow line breaks, r'\\\\' are 2 \ for regexes
     config['preproc'].append([REGEX_LINEBREAK, 'LINEBREAK'])
 
     # Highlight hashtags.
-    config['preproc'].append([HASHTAG.pattern, r'\1{\2\3|color:red}'])
+    if target == 'tex':
+        config['preproc'].append([HASHTAG.pattern, r'\1{\2\3BEGININDEX\3ENDINDEX|color:red}'])
+    else:
+        config['preproc'].append([HASHTAG.pattern, r'\1{\2\3|color:red}'])
 
     # Escape color markup.
-    config['preproc'].append([r'\{(.*?)\|color:(.+?)\}',
-                              r'BEGINCOLOR\1SEP\2ENDCOLOR'])
+    config['preproc'].append([r'\{(.*?)\|color:(.+?)\}', ESCAPE_COLOR])
 
-    if type == 'xhtml' or type == 'html':
+    if target in ['xhtml', 'html']:
         config['encoding'] = 'UTF-8'  # document encoding
         config['toc'] = 0
         config['css-sugar'] = 1
@@ -223,9 +216,6 @@ def _get_config(type):
         # Fix encoding for export opened in firefox
         config['postproc'].append([r'<head>', '<head>' + CHARSET_UTF8])
 
-        # Custom css
-        config['postproc'].append([r'</head>', CSS + '</head>'])
-
         # Line breaks
         config['postproc'].append([r'LINEBREAK', '<br />'])
 
@@ -233,16 +223,15 @@ def _get_config(type):
         config['postproc'].append([r'src=\"WIDTH(\d+)-', r'width="\1" src="'])
 
         # {{red text|color:red}} -> <span style="color:red">red text</span>
-        config['postproc'].append([r'BEGINCOLOR(.*?)SEP(.*?)ENDCOLOR',
-                                   r'<span style="color:\2">\1</span>'])
+        config['postproc'].append([COLOR_ESCAPED, r'<span style="color:\2">\1</span>'])
 
-    elif type == 'tex':
+    elif target == 'tex':
         config['encoding'] = 'utf8'
         config['preproc'].append(['€', 'Euro'])
 
         # Latex only allows whitespace and underscores in filenames if
         # the filename is surrounded by "...". This is in turn only possible
-        # if the extension is omitted
+        # if the extension is omitted.
         config['preproc'].append([r'\[""', r'["""'])
         config['preproc'].append([r'""\.', r'""".'])
 
@@ -250,7 +239,6 @@ def _get_config(type):
 
         # For images we have to omit the file:// prefix
         config['postproc'].append([r'includegraphics\{(.*)"%s' % scheme, r'includegraphics{"\1'])
-        #config['postproc'].append([r'includegraphics\{"file://', r'includegraphics{"'])
 
         # Special handling for LOCAL file links (Omit scheme, add run:)
         # \htmladdnormallink{file.txt}{file:///home/user/file.txt}
@@ -273,11 +261,18 @@ def _get_config(type):
         config['preproc'].append([r'\\\(\s*(.+?)\s*\\\)', r"BEGINMATH''\1''ENDMATH"])
         config['postproc'].append([r'BEGINMATH(.+)ENDMATH', r'$\1$'])
 
-        # BEGINCOLORred textSEPRedENDCOLOR -> r'\\textcolor{Red}{red text}'
-        config['postproc'].append([r'BEGINCOLOR(.*?)SEP(.*?)ENDCOLOR',
-                                   r'\\textcolor{\2}{\1}'])
+        # Fix utf8 quotations - „, “ and ” cause problems compiling the latex document.
+        config['postproc'].extend([[u'„', '"'], [u'”', '"'], [u'“', '"']])
 
-    elif type == 'txt':
+        # Enable index.
+        config['style'].append('makeidx')
+        config['postproc'].append([r'BEGININDEX(.+?)ENDINDEX', r'\\index{\1}'])
+        config['postproc'].append(['begin{document}', 'makeindex\n\\\\begin{document}'])
+        config['postproc'].append(['end{document}', 'printindex\n\n\\\\end{document}'])
+
+        config['postproc'].append([COLOR_ESCAPED, r'\\textcolor{\2}{\1}'])
+
+    elif target == 'txt':
         # Line breaks
         config['postproc'].append([r'LINEBREAK', '\n'])
 
@@ -286,14 +281,28 @@ def _get_config(type):
 
     # Allow resizing images by changing
     # [filename.png?width] to [WIDTHwidth-filename.png]
-    img_ext = r'png|jpe?g|gif|eps|bmp'
+    img_ext = r'png|jpe?g|gif|eps|bmp|svg'
     img_name = r'\S.*\S|\S'
 
     # Apply this prepoc only after the latex image quotes have been added
     config['preproc'].append([r'\[(%s\.(%s))\?(\d+)\]' % (img_name, img_ext), r'[WIDTH\3-\1]'])
 
     # Disable colors for all other targets.
-    config['postproc'].append([r'BEGINCOLOR(.*?)SEP(.*?)ENDCOLOR', r'\1'])
+    config['postproc'].append([COLOR_ESCAPED, r'\1'])
+
+    # MathJax
+    if options.pop('add_mathjax'):
+        config['postproc'].append([r'</body>', MATHJAX + '</body>'])
+
+    config['postproc'].append([r'</body>', PRINT_FUNCTION + '</body>'])
+
+    # Custom css
+    fonts = options.pop('font', 'sans-serif')
+    if 'html' in target:
+        css = CSS % {'font': fonts, 'table_head_bg': TABLE_HEAD_BG}
+        config['postproc'].append([r'</head>', css + '</head>'])
+
+    config.update(options)
 
     return config
 
@@ -336,10 +345,14 @@ def convert(txt, target, data_dir, headers=None, options=None):
     '''
     Code partly taken from txt2tags tarball
     '''
+    options = options or {}
+
     # Only add MathJax code if there is a formula.
-    add_mathjax = (FORMULAS_SUPPORTED and 'html' in target and
-                   any(x in txt for x in MATHJAX_DELIMITERS))
-    logging.debug('add_mathjax: %s' % add_mathjax)
+    options['add_mathjax'] = (
+        FORMULAS_SUPPORTED and
+        'html' in target and
+        any(x in txt for x in MATHJAX_DELIMITERS))
+    logging.debug('Add mathjax code: %s' % options['add_mathjax'])
 
     # Turn relative paths into absolute paths.
     txt = _convert_paths(txt, data_dir)
@@ -355,17 +368,7 @@ def convert(txt, target, data_dir, headers=None, options=None):
         else:
             headers = ['', '', '']
 
-    config = _get_config(target)
-
-    # MathJax
-    if add_mathjax:
-        config['postproc'].append([r'</body>', MATHJAX + '</body>'])
-
-    config['outfile'] = txt2tags.MODULEOUT  # results as list
-    config['target'] = target
-
-    if options is not None:
-        config.update(options)
+    config = _get_config(target, options)
 
     # Let's do the conversion
     try:
@@ -378,12 +381,13 @@ def convert(txt, target, data_dir, headers=None, options=None):
         finished = txt2tags.finish_him(full_doc, config)
         result = '\n'.join(finished)
     # Txt2tags error, show the messsage to the user
-    except txt2tags.error, msg:
+    except txt2tags.error as msg:
         logging.error(msg)
         result = msg
     # Unknown error, show the traceback to the user
     except:
-        result = ('<b>Error</b>: This day contains invalid '
+        result = (
+            '<b>Error</b>: This day contains invalid '
             '<a href="http://txt2tags.org/markup.html">txt2tags markup</a>. '
             'You can help us fix this by submitting a bugreport in the '
             '<a href="https://code.google.com/p/txt2tags/issues/list">'
@@ -430,7 +434,7 @@ def convert_to_pango(txt, headers=None, options=None):
         result = ''.join(finished)
 
     # Txt2tags error, show the messsage to the user
-    except txt2tags.error, msg:
+    except txt2tags.error as msg:
         logging.error(msg)
         result = msg
 
@@ -452,11 +456,10 @@ def convert_to_pango(txt, headers=None, options=None):
     result = re.sub(REGEX_HTML_LINK, replace_links, result)
 
     try:
-        attr_list, plain, accel = pango.parse_markup(result)
-
-        # result is valid pango markup, return the markup
+        Pango.parse_markup(result, -1, "0")
+        # result is valid pango markup, return the markup.
         return result
-    except gobject.GError:
+    except GObject.GError:
         # There are unknown tags in the markup, return the original text
         logging.debug('There are unknown tags in the markup: %s' % result)
         return original_txt
@@ -479,10 +482,3 @@ def convert_from_pango(pango_markup):
     logging.log(5, 'Converted "%s" pango to "%s" txt2tags' %
                 (repr(original_txt), repr(pango_markup)))
     return pango_markup
-
-
-if __name__ == '__main__':
-    from rednotebook.util.utils import show_html_in_browser
-    markup = 'Aha\n\tThis is a quote. It looks very nice. Even with many lines'
-    html = convert(markup, 'xhtml', '/tmp')
-    show_html_in_browser(html, '/tmp/test.html')
